@@ -11,7 +11,7 @@ def login_required(path = 'login'):
             if request.is_authenticated:
                 return func(request, *args, **kwargs)
             messages_broker.add_message(request,'You must login')
-            return redirect(request, f'/{path}',)
+            return redirect(request, f'{path}')
         
         return innder
     return decorator
\ No newline at end of file
